.. _spkg_websocket_client:

websocket_client: WebSocket client for Python with low level API options
========================================================================

Description
-----------

WebSocket client for Python with low level API options

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/websocket-client/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.6.4

version_requirements.txt::

    websocket-client

Equivalent System Packages
--------------------------

(none known)
